<?php

namespace Drupal\webform_as_node\EventSubscriber;

use Drupal\node\Entity\Node;
use Drupal\webform\Entity\Webform;
use Drupal\Core\Database\Database;
use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class EntityTypeSubscriber.
 *
 * @package Drupal\custom_events\EventSubscriber
 */
class ConfigSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   *
   * @return array
   *   The event names to listen for, and the methods that should be executed.
   */
  public static function getSubscribedEvents() {
    return [
      ConfigEvents::SAVE => 'configSave',
    ];
  }

  /**
   * React to a config object being saved.
   *
   * @param \Drupal\Core\Config\ConfigCrudEvent $event
   *   Config crud event.
   */
  public function configSave(ConfigCrudEvent $event) {
    $config = $event->getConfig();
    $webform_config = $config->getName();
    if (preg_match('/^webform\.webform\.(.*)$/', $webform_config, $result) && $result) {
      $webform_id = $result[1];
      $newTitle = $config->get('title');

      // Get matching nid and sync titles.
      $conn = Database::getConnection();
      $rows = $conn->select('webform_as_node')
                   ->fields('webform_as_node',['nid'])
                   ->condition('webform_id',$webform_id)
                   ->execute()
                   ->fetchAll();
      if (count($rows) == 1) {
        if ($node = Node::load($rows[0]->nid)) {
          if ($newTitle != $node->getTitle()) {
            $node->setTitle($newTitle);
            $node->save();
          }
        }
      }
    }
  }
}
